<script src="{{STATIC_URL}}js/plugins/jquery.form.js"></script>
<script src="{{STATIC_URL}}js/plugins/jquery.Jcrop.min.js"></script>
<script src="{{STATIC_URL}}js/plugins/jquery.SimpleCropper.js"></script>
<script src="{{STATIC_URL}}js/plugins/facebook-canvas.js"></script>
<script src="{{STATIC_URL}}js/paintedword.js"></script>